%global so_version 9.2

Summary:        Port of http_parser to llparse
Name:           llhttp
Version:        9.2.1
Release:        2%{?dist}
License:        MIT
URL:            https://github.com/nodejs/llhttp
Source0:        %{url}/archive/v%{version}/llhttp-%{version}.tar.gz
Source1:        llhttp-packaging-bundler
Source2:        llhttp-%{version}-nm-dev.tar.zst
Source3:        check-null-licenses
Source4:        audited-null-licenses.toml

BuildRequires:  make cmake gcc gcc-c++
BuildRequires:  python3-devel python3dist(tomli) nodejs-devel

ExclusiveArch:  x86_64 aarch64 ppc64le loongarch64 riscv64


%description
This project aims to make http_parser maintainable, verifiable and
improving benchmarks where possible. It is a port of http_parser to
TypeScript. llparse is used to generate the output C source file, which
could be compiled and linked with the embedder's program (like Node.js).
This copy of the library is compiled with LLHTTP_STRICT_MODE set to 0
(disabled), which is the default.


%package devel
Summary:        Development files for llhttp
Requires:       llhttp = %{version}-%{release}

%description devel
The llhttp-devel package contains libraries and header files for
developing applications that use llhttp.


%prep
%autosetup
sed -r -i 's@([[:blank:]]*)(.*-m(sse4))@\1// \2@' test/fixtures/index.ts
sed -r -i 's@ -[Og].\b@@g' Makefile

tar --zstd --extract --file='%{SOURCE2}'
mkdir -p node_modules
pushd node_modules
ln -s ../node_modules_dev/* .
ln -s ../node_modules_dev/.bin .
popd

sed -r -i 's@\bnpx[[:blank:]](ts-node)\b@node_modules/.bin/\1@' Makefile


%build
%make_build release RELEASE='%{version}'
rm -rvf node_modules

cd release
%cmake
%cmake_build


%install
cd release
%cmake_install


%check
mkdir -p node_modules
pushd node_modules
ln -s ../node_modules_dev/* .
ln -s ../node_modules_dev/.bin .
popd

%{python3} '%{SOURCE3}' --exceptions '%{SOURCE4}' --with dev node_modules_dev

%set_build_flags
export CXXFLAGS="${CXXFLAGS-} -fpermissive"
export CFLAGS="${CFLAGS-} -fpermissive"
export CLANG=gcc


NODE_ENV=test node -r ts-node/register/type-check ./test/md-test.ts

%files
%license release/LICENSE-MIT
%{_libdir}/libllhttp.so.%{so_version}{,.*}

%files devel
%doc release/README.md
%{_includedir}/llhttp.h
%{_libdir}/libllhttp.so
%{_libdir}/pkgconfig/libllhttp.pc
%{_libdir}/cmake/llhttp/


%changelog
* Fri Aug 16 2024 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 9.2.1-2
- Rebuilt for loongarch release

* Thu May 30 2024 maxonxie <maxonxie@tencent.com> - 9.2.1-1
- Update to 9.2.1 fix CVE-2024-27982

* Tue May 7 2024 Pengda Dou <doupengda@loongson.cn> - 9.2.0-2
- add support for loongarch64

* Thu Apr 11 2024 maxonxie <maxonxie@tencent.com> - 9.2.0-1
- Update to 9.2.0 require by aiohttp 3.9.3

* Fri Sep 08 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 8.1.0-6
- Rebuilt for OpenCloudOS Stream 23.09

* Tue Jul 25 2023 Miaojun Dong <zoedong@tencent.com> - 8.1.0-5
- Rebuild for nodejs-18.14.2

* Fri Apr 28 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 8.1.0-4
- Rebuilt for OpenCloudOS Stream 23.05

* Tue Apr 04 2023 Miaojun Dong <zoedong@tencent.com> - 8.1.0-3
- Fix rebuilt for OpenCloudOS Stream 23

* Fri Mar 31 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 8.1.0-2
- Rebuilt for OpenCloudOS Stream 23

* Fri Mar 10 2023 Miaojun Dong <zoedong@tencent.com> - 8.1.0-1
- initial build
